"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationParser = void 0;
class ValidationParser {
    constructor() {
        this.validators = {};
        this.existParams = [];
    }
    parseElements(elements, element, _block, _filename) {
        if (element.name === "apivalidator") {
            elements.pop();
            const splitted = element.content.split(" ");
            const validator = splitted.shift();
            if (!validator) {
                return;
            }
            const validatorDetails = parseValidatorDetails(validator);
            const validatorDescription = splitted.join(" ");
            if (validatorDetails) {
                this.validators[validatorDetails.name] = {
                    name: validatorDetails.name,
                    description: validatorDescription,
                    paramCount: validatorDetails.params.length
                };
            }
        }
        else if (element.name === "apivalidate") {
            elements.pop();
            const splitted = element.content.split(" ");
            const paramName = splitted.shift();
            const validator = splitted.shift();
            const optDescription = splitted.join(" ").trim();
            if (!validator || !paramName) {
                return;
            }
            const validatorDetails = parseValidatorDetails(validator);
            if (!validatorDetails) {
                return;
            }
            if (!this.validators[validatorDetails.name] ||
                validatorDetails.params.length
                    !== this.validators[validatorDetails.name].paramCount) {
                return;
            }
            const paramIndex = this.searchLastParam(elements, paramName);
            if (typeof paramIndex === "undefined") {
                return;
            }
            let append = "";
            if (!this.existParams.includes(paramName)) {
                append += "<h4> Validation Rules:-</h4>";
            }
            this.existParams.push(paramName);
            append += "- <code>"
                + validatorDetails.name;
            if (validatorDetails.params.length > 0) {
                append += ":" + validatorDetails.params.join(":");
            }
            append += "</code> - ";
            if (optDescription && optDescription.trim() !== "") {
                append += optDescription;
            }
            else {
                append += this.validators[validatorDetails.name].description;
            }
            append += "<br/>";
            elements[paramIndex].content += append;
            elements[paramIndex].source += append;
        }
    }
    searchLastParam(elements, name) {
        const length = elements.length;
        for (let i = length - 1; i >= 0; i--) {
            const curElement = elements[i];
            const splitted = curElement.content.split(" ");
            if (curElement.name === "apiparam" &&
                (!splitted[0].startsWith("{") &&
                    !splitted[0].endsWith("}") &&
                    splitted[0] === name
                    ||
                        splitted[1] === name)) {
                return i;
            }
        }
        return undefined;
    }
}
exports.ValidationParser = ValidationParser;
const parseValidatorDetails = (validator) => {
    const validatorParams = validator.split(":");
    const validatorName = validatorParams.shift();
    if (validatorName) {
        return { name: validatorName, params: validatorParams };
    }
    return undefined;
};
//# sourceMappingURL=ValidationParser.js.map